==> grib2io-0.9.1.tar.gz: grib2io-0.9.1/grib2io/tables/section1.py <==
table_1_0 = {
'0':'Experimental',
'1':'Version Implemented on 7 November 2001',
'2':'Version Implemented on 4 November 2003',
'3':'Version Implemented on 2 November 2005',
'4':'Version Implemented on 7 November 2007',
'5':'Version Implemented on 4 November 2009',
'6':'Version Implemented on 15 September 2010',
'7':'Version Implemented on 4 May 2011',
'8':'Version Implemented on 8 November 2011',
'9':'Version Implemented on 2 May 2012',
'10':'Version Implemented on 7 November 2012',
'11':'Version Implemented on 8 May 2013',
'12':'Version Implemented on 14 November 2013',
'13':'Version Implemented on 7 May 2014',
'14':'Version Implemented on 5 November 2014',
'16':'Version Implemented on 11 November 2015',
'17':'Version Implemented on 4 May 2016',
'18':'Version Implemented on 2 November 2016',
'19':'Version Implemented on 3 May 2017',
'20':'Version Implemented on 8 November 2017',
'21':'Version Implemented on 2 May 2018',
'22':'Version Implemented on 7 November 2018',
'23':'Version Implemented on 15 May 2019',
'24':'Version Implemented on 06 November 2019',
'25':'Pre-operational to be implemented by next amendment',
'26-254':'Future Version',
'255':'Missing"',
}

table_1_1 = {
'0':'Local tables not used. Only table entries and templates from the current master table are valid.',
'1-254':'Number of local table version used.',
'255':'Missing',
}

table_1_2 = {
'0':'Analysis',
'1':'Start of Forecast',
'2':'Verifying Time of Forecast',
'3':'Observation Time',
'4-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_1_3 = {
'0':'Operational Products',
'1':'Operational Test Products',
'2':'Research Products',
'3':'Re-Analysis Products',
'4':'THORPEX Interactive Grand Global Ensemble (TIGGE)',
'5':'THORPEX Interactive Grand Global Ensemble (TIGGE) test',
'6':'S2S Operational Products',
'7':'S2S Test Products',
'8':'Uncertainties in ensembles of regional reanalysis project (UERRA)',
'9':'Uncertainties in ensembles of regional reanalysis project (UERRA) Test',
'10-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_1_4 = {
'0':'Analysis Products',
'1':'Forecast Products',
'2':'Analysis and Forecast Products',
'3':'Control Forecast Products',
'4':'Perturbed Forecast Products',
'5':'Control and Perturbed Forecast Products',
'6':'Processed Satellite Observations',
'7':'Processed Radar Observations',
'8':'Event Probability',
'9-191':'Reserved',
'192-254':'Reserved for Local Use',
'192':'Experimental Products',
'255':'Missing',
}

table_1_5 = {
'0':'Calendar Definition',
'1':'Paleontological Offset',
'2':'Calendar Definition and Paleontological Offset',
'3-32767':'Reserved',
'32768-65534':'Reserved for Local Use',
'65535':'Missing',
}

table_1_6 = {
'0':'Gregorian',
'1':'360-day',
'2':'365-day',
'3':'Proleptic Gregorian',
'4-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

==> grib2io-1.0.3.tar.gz: grib2io-1.0.3/grib2io/tables/section1.py <==
table_1_0 = {
'0':'Experimental',
'1':'Version Implemented on 7 November 2001',
'2':'Version Implemented on 4 November 2003',
'3':'Version Implemented on 2 November 2005',
'4':'Version Implemented on 7 November 2007',
'5':'Version Implemented on 4 November 2009',
'6':'Version Implemented on 15 September 2010',
'7':'Version Implemented on 4 May 2011',
'8':'Version Implemented on 8 November 2011',
'9':'Version Implemented on 2 May 2012',
'10':'Version Implemented on 7 November 2012',
'11':'Version Implemented on 8 May 2013',
'12':'Version Implemented on 14 November 2013',
'13':'Version Implemented on 7 May 2014',
'14':'Version Implemented on 5 November 2014',
'16':'Version Implemented on 11 November 2015',
'17':'Version Implemented on 4 May 2016',
'18':'Version Implemented on 2 November 2016',
'19':'Version Implemented on 3 May 2017',
'20':'Version Implemented on 8 November 2017',
'21':'Version Implemented on 2 May 2018',
'22':'Version Implemented on 7 November 2018',
'23':'Version Implemented on 15 May 2019',
'24':'Version Implemented on 06 November 2019',
'25':'Pre-operational to be implemented by next amendment',
'25':'Version Implemented on 06 May 2020',
'26':'Pre-operational to be implemented by next amendment',
'27-254':'Future Version',
'255':'Missing"',
}

table_1_1 = {
'0':'Local tables not used. Only table entries and templates from the current master table are valid.',
'1-254':'Number of local table version used.',
'255':'Missing',
}

table_1_2 = {
'0':'Analysis',
'1':'Start of Forecast',
'2':'Verifying Time of Forecast',
'3':'Observation Time',
'4':'Local Time',
'5-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_1_3 = {
'0':'Operational Products',
'1':'Operational Test Products',
'2':'Research Products',
'3':'Re-Analysis Products',
'4':'THORPEX Interactive Grand Global Ensemble (TIGGE)',
'5':'THORPEX Interactive Grand Global Ensemble (TIGGE) test',
'6':'S2S Operational Products',
'7':'S2S Test Products',
'8':'Uncertainties in ensembles of regional reanalysis project (UERRA)',
'9':'Uncertainties in ensembles of regional reanalysis project (UERRA) Test',
'10':'Copernicus Regional Reanalysis',
'11':'Copernicus Regional Reanalysis Test',
'12-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}

table_1_4 = {
'0':'Analysis Products',
'1':'Forecast Products',
'2':'Analysis and Forecast Products',
'3':'Control Forecast Products',
'4':'Perturbed Forecast Products',
'5':'Control and Perturbed Forecast Products',
'6':'Processed Satellite Observations',
'7':'Processed Radar Observations',
'8':'Event Probability',
'9-191':'Reserved',
'192-254':'Reserved for Local Use',
'192':'Experimental Products',
'255':'Missing',
}

table_1_5 = {
'0':'Calendar Definition',
'1':'Paleontological Offset',
'2':'Calendar Definition and Paleontological Offset',
'3-32767':'Reserved',
'32768-65534':'Reserved for Local Use',
'65535':'Missing',
}

table_1_6 = {
'0':'Gregorian',
'1':'360-day',
'2':'365-day',
'3':'Proleptic Gregorian',
'4-191':'Reserved',
'192-254':'Reserved for Local Use',
'255':'Missing',
}
